@@ -1,5 +1,5 @@
 con_boot_lm <- function(object, B = 999, fixed = FALSE, Amat, 
-                        bvec, meq, se = "none", mix.weights = "none", 
+                        bvec, meq, se = "none", mix_weights = "none", 
                         parallel = parallel, ncpus = ncpus, cl = cl) { 
     
   DATA <- as.data.frame(object$model)
@@ -7,7 +7,7 @@ con_boot_lm <- function(object, B = 999, fixed = FALSE, Amat,
     # standard bootstrap
     bootout <- boot(DATA, con_boot_data, R = B, object = object, 
                     constraints = Amat, rhs = bvec, neq = meq, 
-                    se = "none", mix.weights = "none", 
+                    se = "none", mix_weights = "none", 
                     parallel = parallel, ncpus = ncpus, cl = cl)
   } else { 
     # model based bootstrap
@@ -16,7 +16,7 @@ con_boot_lm <- function(object, B = 999, fixed = FALSE, Amat,
     bootout <- boot(data.frame(DATA, fit = fit, res = res), 
                     con_boot_fixed, R = B, object = object, 
                     constraints = Amat, rhs = bvec, neq = meq, 
-                    se = "none", mix.weights = "none", 
+                    se = "none", mix_weights = "none", 
                     parallel = parallel, ncpus = ncpus, cl = cl)
   }
   
