@@ -39,6 +39,13 @@ calculate_power <- function(density_h1, critical_value) {
   sum(density_h1$y[density_h1$x > critical_value]) * mean(diff(density_h1$x))
 }
 
+# Function to calculate density
+# calculate_density <- function(data, var, sample_value) {
+#   dens <- density(data[[var]], kernel = "gaussian", na.rm = TRUE, bw = "nrd0")
+#   data.frame(x = dens$x, y = dens$y, sample_value = sample_value)
+# }
+
+
 # Extract the parts within the parentheses
 extract_in_parentheses <- function(name) {
   regmatches(name, regexpr("\\(.*\\)", name))
@@ -54,103 +61,30 @@ construct_colnames <- function(list_name, colnames, pref_hypo_name) {
   remove_spaces_in_parentheses(paste0(list_name, " (", pref_hypo_name, " ", colnames, ")", sep = ""))
 }
 
-plot_all_groups <- function(plot_df, groups, title, xlabel, x_lim = NULL, 
-                            alpha = 0.5, distr_grid = FALSE, 
-                            percentiles = c(0.05, 0.95)) {
-  plot_list <- list()
-  for (group in groups) {
-    plot <- create_density_plot(plot_df, group, title, xlabel, x_lim, alpha, 
-                                distr_grid, percentiles)
-    plot_list[[group]] <- plot
-  }
-  return(plot_list)
+combine_matrices_cbind <- function(lst) {
+  df_list <- lapply(lst, as.data.frame)
+  combined_df <- do.call(cbind, df_list)
+  return(combined_df)
 }
 
-# benchmark plots
-create_density_plot <- function(plot_df, group_comparison, title, xlabel,
-                                x_lim = NULL, alpha = 0.5, distr_grid = FALSE,
-                                percentiles = c(0.05, 0.95)) {
-  
-  df_subset <- subset(plot_df, Group_hypo_comparison == group_comparison)
-  
-  if (!is.null(df_subset$Group_hypo_comparison)) {
-    title <- paste(title, "vs.", sub(".*vs\\. ", "", unique(df_subset$Group_hypo_comparison)))
-  }
-  
-  # Function to calculate density
-  calculate_density <- function(data, var, sample_value) {
-    dens <- density(data[[var]], kernel = "gaussian", from = 0)
-    data.frame(x = dens$x, y = dens$y, sample_value = sample_value)
-  }
-  
-  # Calculate densities for each group
-  # density_data <- df_subset %>%
-  #   group_by(Group_pop_values) %>%
-  #   do(calculate_density(., "Value", unique(.$sample_value))) %>%
-  #   ungroup()
-  
-  group_levels <- unique(df_subset$Group_pop_values)
-  density_data <- do.call(rbind, lapply(group_levels, function(group) {
-    data <- subset(df_subset, Group_pop_values == group)
-    dens <- calculate_density(data, var = "Value", sample_value = data$sample_value[1])
-    dens$Group_pop_values <- group
-    dens$sample_value <- unique(data$sample_value)
-    dens
-  }))
 
-  percentile_label <- paste0("[", percentiles[1]*100, ", ", percentiles[2]*100, "]th Percentiles")
-  percentile_first_group_lower <- df_subset$lb_first_group[1]
-  percentile_first_group_upper <- df_subset$ub_first_group[1]
-  formatted_sample_value <- sprintf("Sample Value = %.3f", unique(df_subset$sample_value)[1])
-  linetype_labels <- unique(c(formatted_sample_value, percentile_label))
+combine_matrices_cbind <- function(lst) {
+  # Vind het maximum aantal rijen in de lijst
+  max_rows <- max(sapply(lst, nrow))
   
-  p <- ggplot(density_data, aes(x = x, y = y, fill = Group_pop_values)) +
-    geom_ribbon(aes(ymin = 0, ymax = y), alpha = alpha) +
-    geom_segment(data = df_subset, aes(x = sample_value, xend = sample_value, 
-                                       y = 0, yend = Inf, linetype = formatted_sample_value), 
-                 color = "red", linewidth = 1) +
-    geom_segment(data = df_subset, aes(x = percentile_first_group_lower, 
-                                       xend = percentile_first_group_lower, y = 0, 
-                                       yend = Inf, linetype = percentile_label), 
-                 color = df_subset$first_group_color[1], linewidth = 1) + 
-    geom_segment(data = df_subset, aes(x = percentile_first_group_upper, 
-                                       xend = percentile_first_group_upper, y = 0, 
-                                       yend = Inf, linetype = percentile_label), 
-                 color = df_subset$first_group_color[1], linewidth = 1) + 
-    #scale_x_continuous(expand = c(0, 0)) +  
-    #scale_y_continuous(expand = c(0, 0)) +  
-    ggtitle(title) +
-    xlab(xlabel) + 
-    ylab("Density") + 
-    theme(axis.text = element_text(size = 11),
-          axis.title.x = element_text(size = 12, margin = margin(t = 10)),
-          axis.title.y = element_text(size = 12, margin = margin(r = 10)),
-          plot.title = element_text(size = 12)) +
-    scale_fill_brewer(palette = "Set2", name = "Distribution under:") +
-    scale_linetype_manual(values = setNames(rep("solid", length(linetype_labels)), linetype_labels), name = "") +
-    theme(legend.key = element_rect(fill = "white")) +
-    labs(fill = "Distribution under:", linetype = "Legend") +
-    guides(fill = guide_legend(order = 1),
-           linetype = guide_legend(order = 2)) 
- 
-  if (distr_grid) {
-    p <- p + facet_grid(. ~ Group_pop_values, scales = "free_x")
-  }
-
-  if (!is.null(x_lim) && length(x_lim) == 2) {
-    p <- p + coord_cartesian(xlim = x_lim)
-  } else {
-    iqr <- IQR(df_subset$Value)
-    #q1 <- quantile(df_subset$Value, 0.05)
-    q3 <- quantile(df_subset$Value, 0.95)
-    #lower_limit <- q1 - 1.5 * iqr
-    upper_limit <- q3 + 1.5 * iqr
-    p <- p + coord_cartesian(xlim = c(0, upper_limit))
-  }
+  # Zet de matrices om naar data frames en vul met NA waar nodig
+  df_list <- lapply(lst, function(x) {
+    as.data.frame(rbind(x, matrix(NA, nrow = max_rows - nrow(x), ncol = ncol(x))))
+  })
   
-  return(p)
+  # Combineer de data frames kolomgewijs
+  combined_df <- do.call(cbind, df_list)
+  
+  return(combined_df)
 }
 
+
+
 detect_intercept <- function(model) {
   coefficients <- model$b.unrestr
   intercept_names <- c("(Intercept)", "Intercept", "(const)", "const", 
@@ -255,6 +189,314 @@ compute_population_means <- function(pop_es, ratio_pop_means, var_e, ngroups) {
 }
 
 
+# this function is called from the goric_benchmark_anova() function
+parallel_function_means <- function(i, N, var_e, means_pop, 
+                                    hypos, pref_hypo, object, ngroups, sample, 
+                                    control, form_model_org, ...) {  
+  # Sample residuals
+  epsilon <- rnorm(sum(N), sd = sqrt(var_e))
+  
+  # original model formula 
+  if (length(form_model_org) > 0) {
+    model <- form_model_org
+    lhs <- all.vars(model)[1]
+    sample[[lhs]] <- as.matrix(sample[, 2:(1 + ngroups)]) %*% matrix(means_pop, 
+                                                                     nrow = ngroups) + epsilon
+    df_boot <- data.frame(lhs = sample[[lhs]], sample[, 2:(1 + ngroups)])
+    colnames(df_boot)[1] <- lhs
+    
+    has_intercept <- attr(terms(model), "intercept") == 1
+    rhs <- as.character(attr(terms(model), "term.labels"))
+    
+    # Create the RHS with all other variables and optionally the intercept
+    if (has_intercept) {
+      new_rhs <- "."
+    } else {
+      new_rhs <- "-1 + ."
+    }
+    
+    # Create the new formula
+    new_model <- as.formula(paste(lhs, "~", new_rhs))
+  } else {
+    new_model <- y ~ 0 + .
+    # Generate data
+    sample$y <- as.matrix(sample[, 2:(1 + ngroups)]) %*% matrix(means_pop, 
+                                                                nrow = ngroups) + epsilon
+    df_boot <- data.frame(y = sample$y, sample[, 2:(1 + ngroups)])
+  }
+  
+  
+  # Obtain fit
+  fit_boot <- lm(new_model, data = df_boot)  
+  
+  results_goric <- tryCatch(
+    {
+      # Voer de goric functie uit
+      goric(fit_boot,
+            hypotheses = hypos,
+            comparison = object$comparison,
+            type = object$type,
+            control = control, 
+            ...)
+    },
+    error = function(e) {
+      # error message 
+      message(paste("Error in iteration", i, ":", e$message))
+      return(NULL)  
+    },
+    warning = function(w) {
+      # warning message
+      message(paste("Warning in iteration", i, ":", w$message))
+      return(NULL)  
+    }
+  )
+  
+  if (is.null(results_goric)) {
+    return(NULL)
+  }
+  
+  # Return the relevant results
+  ld_names <- names(results_goric$ratio.gw[pref_hypo, ])
+  ld <- results_goric$result$loglik[pref_hypo] - results_goric$result$loglik
+  names(ld) <- ld_names
+  
+  list(
+    #test  = attr(results.goric$objectList[[results.goric$objectNames]]$wt.bar, "mvtnorm"),
+    gw  = results_goric$result[pref_hypo, 7], # goric(a) weight
+    rgw = results_goric$ratio.gw[pref_hypo, ], # ratio goric(a) weights
+    rlw = results_goric$ratio.lw[pref_hypo, ], # ratio likelihood weights
+    ld  = ld # loglik difference
+  )
+}
+
+
+# this function is called from the benchmark_asymp() function
+parallel_function_asymp <- function(i, est, VCOV, hypos, pref_hypo, comparison,
+                                    type, control, ...) {  
+  results_goric <- tryCatch(
+    {
+      # Voer de goric functie uit
+      goric(est[i, ], VCOV = VCOV,
+            hypotheses = hypos,
+            comparison = comparison,
+            type = type,
+            control = control, 
+            ...)
+    },
+    error = function(e) {
+      # error message 
+      message(paste("Error in iteration", i, ":", e$message))
+      return(NULL)  
+    },
+    warning = function(w) {
+      # warning message
+      message(paste("Warning in iteration", i, ":", w$message))
+      return(NULL)  
+    }
+  )
+  
+  if (is.null(results_goric)) {
+    return(NULL)
+  }
+  
+  ld_names <- names(results_goric$ratio.gw[pref_hypo, ])
+  ld <- results_goric$result$loglik[pref_hypo] - results_goric$result$loglik
+  names(ld) <- ld_names
+  
+  out <- list(
+    gw  = results_goric$result[pref_hypo, 7], # goric(a) weight
+    rgw = results_goric$ratio.gw[pref_hypo, ], # ratio goric(a) weights
+    rlw = results_goric$ratio.lw[pref_hypo, ], # ratio likelihood weights
+    ld  = ld
+  )
+  
+  return(out)
+}
+
+
+# parallel_function_asymp <- function(i, est, VCOV, hypos, pref_hypo, comparison,
+#                                     type, control, ...) {  
+#   
+#   results_goric <- try(goric(est[i, ], VCOV = VCOV,
+#                              hypotheses = hypos,
+#                              comparison = comparison,
+#                              type = type,
+#                              control = control, 
+#                              ...), silent = TRUE
+#   )
+#   
+#   if (inherits(results_goric, "try-error")) {
+#     warning("Error encountered: ", attr(results_goric, "condition")$message)
+#     return(NULL)
+#   }
+# 
+#   # Return the relevant results
+#   ld_names <- names(results_goric$ratio.gw[pref_hypo, ])
+#   ld <- results_goric$result$loglik[pref_hypo] - results_goric$result$loglik
+#   names(ld) <- ld_names
+#   
+#   out <- list(
+#     #test  = attr(results.goric$objectList[[results.goric$objectNames]]$wt.bar, "mvtnorm"),
+#     gw  = results_goric$result[pref_hypo, 7], # goric(a) weight
+#     rgw = results_goric$ratio.gw[pref_hypo, ], # ratio goric(a) weights
+#     rlw = results_goric$ratio.lw[pref_hypo, ], # ratio likelihood weights
+#     ld  = ld
+#   )
+#   return(out)
+# }
+
+
+# Define a function to extract and combine values from all elements in each pop_es list
+extract_and_combine_values <- function(pop_es_list, value_name) {
+  empty_lists_count <- sum(sapply(pop_es_list, is.null))
+  #print(empty_lists_count)
+  # remove empty lists (is.na)
+  #pop_es_list <- pop_es_list[!sapply(pop_es_list, function(x) any(is.na(x)))]
+  out <- do.call(rbind, lapply(pop_es_list, function(sub_list) sub_list[[value_name]]))
+  attr(out, "empty_lists_count") <- empty_lists_count
+  
+  return(out)
+}
+
+
+## 
+get_results_benchmark <- function(x, object, pref_hypo, pref_hypo_name, 
+                                  quant, names_quant, nr.hypos) {
+  results <- x
+
+  # Use lapply to apply the extract_and_combine_values function to each element in the results list
+  gw_combined  <- lapply(results, function(pop_es_list) extract_and_combine_values(pop_es_list, "gw"))
+  rgw_combined <- lapply(results, function(pop_es_list) extract_and_combine_values(pop_es_list, "rgw"))
+  rlw_combined <- lapply(results, function(pop_es_list) extract_and_combine_values(pop_es_list, "rlw"))
+  ld_combined  <- lapply(results, function(pop_es_list) extract_and_combine_values(pop_es_list, "ld"))
+  
+  # Calculate CI_benchmarks_gw for each pop_es category
+  CI_benchmarks_gw <- lapply(gw_combined, function(gw_values) {
+    CI_benchmarks_gw <- matrix(c(object$result[pref_hypo, 7], quantile(gw_values, 
+                                                                       quant, na.rm = TRUE)), 
+                               nrow = 1)
+    colnames(CI_benchmarks_gw) <- names_quant
+    rownames(CI_benchmarks_gw) <- pref_hypo_name
+    CI_benchmarks_gw
+  })
+  
+  
+  # Initialize matrices to store CI benchmarks for current pop_es category
+  CI_benchmarks_rgw <- matrix(NA, nrow = nr.hypos, ncol = 1 + length(quant))
+  CI_benchmarks_rlw <- matrix(NA, nrow = nr.hypos, ncol = 1 + length(quant))
+  CI_benchmarks_rlw_ge1 <- matrix(NA, nrow = nr.hypos, ncol = 1 + length(quant))
+  CI_benchmarks_ld <- matrix(NA, nrow = nr.hypos, ncol = 1 + length(quant))
+  CI_benchmarks_ld_ge0 <- matrix(NA, nrow = nr.hypos, ncol = 1 + length(quant))
+  
+  # Fill the first column with sample values
+  CI_benchmarks_rgw[, 1] <- object$ratio.gw[pref_hypo,] 
+  CI_benchmarks_rlw[, 1] <- object$ratio.lw[pref_hypo,] 
+  for (j in seq_len(nr.hypos)) {
+    if (object$ratio.lw[pref_hypo, j] >= 1) {
+      CI_benchmarks_rlw_ge1[j, 1] <- object$ratio.lw[pref_hypo, j] 
+    } else {
+      CI_benchmarks_rlw_ge1[j, 1] <- 1 / object$ratio.lw[pref_hypo, j] 
+    }
+  }
+  CI_benchmarks_ld[, 1] <- object$result$loglik[pref_hypo] - object$result$loglik 
+  CI_benchmarks_ld_ge0[, 1] <- abs(object$result$loglik[pref_hypo] - object$result$loglik) 
+  
+  CI_benchmarks_rgw_all <- list()
+  CI_benchmarks_rlw_all <- list()
+  CI_benchmarks_rlw_ge1_all <- list()
+  CI_benchmarks_ld_all <- list()
+  CI_benchmarks_ld_ge0_all <- list()
+  
+  # Loop through each pop_es category to fill in the CI benchmark lists
+  for (name in names(results)) {
+    rgw_combined_values <- rgw_combined[[name]]
+    rlw_combined_values  <- rlw_combined[[name]]
+    ld_combined_values  <- ld_combined[[name]]
+    
+    # Prepare rlw_ge1 and ld_ge0 matrices
+    rlw_ge1 <- rlw_combined_values
+    rlw_ge1[rlw_combined_values < 1] <- 1 / rlw_combined_values[rlw_combined_values < 1]
+    ld_ge0 <- abs(ld_combined_values)
+    
+    # Loop through the hypotheses and calculate the quantiles
+    for (j in seq_len(nr.hypos)) {
+      CI_benchmarks_rgw[j, 2:(1 + length(quant))] <- quantile(rgw_combined_values[, j], quant, na.rm = TRUE)
+      CI_benchmarks_rlw[j, 2:(1 + length(quant))] <- quantile(rlw_combined_values[, j], quant, na.rm = TRUE)
+      CI_benchmarks_rlw_ge1[j, 2:(1 + length(quant))] <- quantile(rlw_ge1[, j], quant, na.rm = TRUE)
+      CI_benchmarks_ld[j, 2:(1 + length(quant))] <- quantile(ld_combined_values[, j], quant, na.rm = TRUE)
+      CI_benchmarks_ld_ge0[j, 2:(1 + length(quant))] <- quantile(ld_ge0[, j], quant, na.rm = TRUE)
+    }
+    
+    # Set column names for the CI benchmarks
+    colnames(CI_benchmarks_rgw) <- colnames(CI_benchmarks_rlw) <- 
+      colnames(CI_benchmarks_rlw_ge1) <- colnames(CI_benchmarks_ld) <- 
+      colnames(CI_benchmarks_ld_ge0) <- names_quant
+    
+    # Set row names for the CI benchmarks
+    rownames(CI_benchmarks_rgw) <- rownames(CI_benchmarks_rlw) <- 
+      rownames(CI_benchmarks_rlw_ge1) <- rownames(CI_benchmarks_ld) <- 
+      rownames(CI_benchmarks_ld_ge0) <- paste(pref_hypo_name, names(object$ratio.gw[pref_hypo, ]))
+    
+    # Store CI benchmarks in lists
+    CI_benchmarks_rgw_all[[name]] <- CI_benchmarks_rgw
+    CI_benchmarks_rlw_all[[name]] <- CI_benchmarks_rlw
+    CI_benchmarks_rlw_ge1_all[[name]] <- CI_benchmarks_rlw_ge1
+    CI_benchmarks_ld_all[[name]] <- CI_benchmarks_ld
+    CI_benchmarks_ld_ge0_all[[name]] <- CI_benchmarks_ld_ge0
+  } 
+  
+  
+  CI_benchmarks_rgw_all_cleaned <- lapply(CI_benchmarks_rgw_all, function(pop_es_list) {
+    remove_single_value_rows(pop_es_list, 1)
+  })
+  
+  CI_benchmarks_rlw_all_cleaned <- lapply(CI_benchmarks_rlw_all, function(pop_es_list) {
+    remove_single_value_rows(pop_es_list, 1)
+  })
+  
+  CI_benchmarks_rlw_ge1_all_cleaned <- lapply(CI_benchmarks_rlw_ge1_all, function(pop_es_list) {
+    remove_single_value_rows(pop_es_list, 1)
+  })
+  
+  CI_benchmarks_ld_all_cleaned <- lapply(CI_benchmarks_ld_all, function(pop_es_list) {
+    remove_single_value_rows(pop_es_list, 0)
+  })
+  
+  CI_benchmarks_ld_ge0_all_cleaned <- lapply(CI_benchmarks_ld_ge0_all, function(pop_es_list) {
+    remove_single_value_rows(pop_es_list, 0)
+  })
+  
+  
+  rgw_combined <- lapply(rgw_combined, function(pop_es_list) {
+    remove_single_value_col(pop_es_list, 1)
+  })
+  
+  rlw_combined <- lapply(rlw_combined, function(pop_es_list) {
+    remove_single_value_col(pop_es_list, 1)
+  })
+  
+  ld_combined <- lapply(ld_combined, function(pop_es_list) {
+    remove_single_value_col(pop_es_list, 0)
+  })
+  
+  
+  OUT <- list(
+    benchmarks_gw = CI_benchmarks_gw,
+    benchmarks_rgw = CI_benchmarks_rgw_all_cleaned,
+    benchmarks_rlw = CI_benchmarks_rlw_all_cleaned,
+    benchmarks_rlw_ge1 = CI_benchmarks_rlw_ge1_all_cleaned,
+    benchmarks_difLL = CI_benchmarks_ld_all_cleaned,
+    benchmarks_absdifLL = CI_benchmarks_ld_ge0_all_cleaned,
+    combined_values = list(gw_combined = gw_combined, 
+                           rgw_combined = rgw_combined, 
+                           rlw_combined = rlw_combined, 
+                           ld_combined = ld_combined)
+  )
+  
+  return(OUT)
+}
+
+
 # Calculate the error probability
 calculate_error_probability <- function(object, hypos, pref_hypo, est, 
                                         VCOV, control, ...) {
@@ -299,93 +541,6 @@ calculate_error_probability <- function(object, hypos, pref_hypo, est,
 
 
 
-# this function is called from the goric_benchmark_anova() function
-parallel_function_means <- function(i, N, var_e, means_pop, 
-                                    hypos, pref_hypo, object, ngroups, sample, 
-                                    control, form_model_org, ...) {  
-  # Sample residuals
-  epsilon <- rnorm(sum(N), sd = sqrt(var_e))
-  
-  # original model formula 
-  if (length(form_model_org) > 0) {
-    model <- form_model_org
-    lhs <- all.vars(model)[1]
-    sample[[lhs]] <- as.matrix(sample[, 2:(1 + ngroups)]) %*% matrix(means_pop, 
-                                                                     nrow = ngroups) + epsilon
-    df_boot <- data.frame(lhs = sample[[lhs]], sample[, 2:(1 + ngroups)])
-    colnames(df_boot)[1] <- lhs
-    
-    has_intercept <- attr(terms(model), "intercept") == 1
-    rhs <- as.character(attr(terms(model), "term.labels"))
-    
-    # Create the RHS with all other variables and optionally the intercept
-    if (has_intercept) {
-      new_rhs <- "."
-    } else {
-      new_rhs <- "-1 + ."
-    }
-    
-    # Create the new formula
-    new_model <- as.formula(paste(lhs, "~", new_rhs))
-  } else {
-    new_model <- y ~ 0 + .
-    # Generate data
-    sample$y <- as.matrix(sample[, 2:(1 + ngroups)]) %*% matrix(means_pop, 
-                                                                nrow = ngroups) + epsilon
-    df_boot <- data.frame(y = sample$y, sample[, 2:(1 + ngroups)])
-  }
-  
-  
-  # Obtain fit
-  fit_boot <- lm(new_model, data = df_boot)  
-  # GORICA or GORICA depending on what is done in data
-  results_goric <- goric(fit_boot,
-                         hypotheses = hypos,
-                         comparison = object$comparison,
-                         type = object$type,
-                         control = control, 
-                         ...)
-  
-  # Return the relevant results
-  ld_names <- names(results_goric$ratio.gw[pref_hypo, ])
-  ld <- results_goric$result$loglik[pref_hypo] - results_goric$result$loglik
-  names(ld) <- ld_names
-  
-  list(
-    #test  = attr(results.goric$objectList[[results.goric$objectNames]]$wt.bar, "mvtnorm"),
-    gw  = results_goric$result[pref_hypo, 7], # goric(a) weight
-    rgw = results_goric$ratio.gw[pref_hypo, ], # ratio goric(a) weights
-    rlw = results_goric$ratio.lw[pref_hypo, ], # ratio likelihood weights
-    ld  = ld # loglik difference
-  )
-}
-
-
-# this function is called from the benchmark_asymp() function
-parallel_function_asymp <- function(i, est, VCOV, hypos, pref_hypo, comparison,
-                                    type, control, ...) {  
-  
-  results_goric <- goric(est[i, ], VCOV = VCOV,
-                         hypotheses = hypos,
-                         comparison = comparison,
-                         type = type,
-                         control = control, 
-                         ...)
-  
-  # Return the relevant results
-  ld_names <- names(results_goric$ratio.gw[pref_hypo, ])
-  ld <- results_goric$result$loglik[pref_hypo] - results_goric$result$loglik
-  names(ld) <- ld_names
-  
-  list(
-    #test  = attr(results.goric$objectList[[results.goric$objectNames]]$wt.bar, "mvtnorm"),
-    gw  = results_goric$result[pref_hypo, 7], # goric(a) weight
-    rgw = results_goric$ratio.gw[pref_hypo, ], # ratio goric(a) weights
-    rlw = results_goric$ratio.lw[pref_hypo, ], # ratio likelihood weights
-    ld  = ld
-  )
-}
-
 # called by the benchmark.print() function
 print_section <- function(header, content_printer, nchar, text_color, reset) {
   cat("\n")
@@ -410,11 +565,12 @@ format_value <- function(value) {
 print_rounded_es_value <- function(df, pop_es, model_type, text_color, reset) {
   if (model_type == "benchmark_asymp") {
     pop_es_value <- gsub("pop_est = ", "", pop_es)
+    cat(sprintf("Population estimates = %s%s%s\n", text_color, pop_es_value, reset))
   } else {
     pop_es_value <- gsub("pop_es = ", "", pop_es)
+    cat(sprintf("Population effect-size = %s%s%s\n", text_color, pop_es_value, reset))
   }
-  cat(sprintf("Population estimates = %s%s%s\n", text_color, pop_es_value, reset))
-
+  
   #formatted_column <- sprintf("%.3f", df)
   formatted_values <- sapply(as.numeric(df), format_value)
   formatted_df <- `dim<-`(formatted_values, dim(df))
@@ -476,19 +632,21 @@ print_rounded_es_value <- function(df, pop_es, model_type, text_color, reset) {
 
 
 print_formatted_matrix <- function(mat, text_color, reset) {
+  row_width <- max(nchar(rownames(mat))) + 0  
   col_widths <- apply(mat, 2, function(col) max(nchar(as.character(col))))
   col_widths <- pmax(col_widths, nchar(colnames(mat))) + 2  
   
   cat("Population Estimates (PE):\n")
-  cat(sprintf("%-10s", ""))
+  #cat(sprintf("%-10s", ""))
+  cat(sprintf(paste0("%-", row_width, "s"), "")) 
   for (k in 1:ncol(mat)) {
     cat(sprintf(paste0("%", col_widths[k], "s"), colnames(mat)[k]))
   }
   cat("\n")
   
-  # Print de rijen
+  # Print rows
   for (i in 1:nrow(mat)) {
-    cat(sprintf("%-10s", rownames(mat)[i]))
+    cat(sprintf(paste0("%-", row_width, "s"), rownames(mat)[i]))
     for (j in 1:ncol(mat)) {
       cat(sprintf(paste0("%s%", col_widths[j], "s%s"), text_color, mat[i, j], reset))
     }
@@ -504,11 +662,11 @@ check_rhs_constants <- function(rhs_list) {
   hypotheses_with_constants <- names(constants_check)[unlist(constants_check)]
   if (length(hypotheses_with_constants) > 0) {
     warning_message <- paste0("Restriktor Warning: The following hypotheses contain constants",
-                              "greater or less than 0: ", 
+                              " greater or less than 0: ", 
                               paste(hypotheses_with_constants, collapse = ", "),
                               ". The default population estimates are likely incorrect.",
-                              "Consider providing custom population estimates via the",
-                              "pop_est argument.")
+                              " Consider providing custom population estimates via the",
+                              " pop_est argument.")
     warning(warning_message, call. = FALSE)
   }
 }
